==> Gridcoin-Research-5.3.3.0.tar.gz: Gridcoin-Research-5.3.3.0/doc/README.md <==
Gridcoin
=============

Setup
---------------------
Gridcoin is a free open source project derived from Bitcoin, with
the goal of providing a long-term energy-efficient cryptocurrency, rewarding BOINC work.
Built on the foundation of Bitcoin, PPCoin and NovaCoin, innovations such as proof-of-stake
help further advance the field of cryptocurrency. The Gridcoin Client downloads and, by default, stores the entire history of Gridcoin transactions; depending on the speed of your computer and network connection, the synchronization process can take anywhere from a few hours to a day or more.

To download Gridcoin, visit [gridcoin.us](https://gridcoin.us).

### Need Help?

* See the documentation at the [Gridcoin Wiki](https://wiki.gridcoin.us/Main_Page)
for help and more information.
* A lot of features core features are based on Bitcoin and have been documented on the [Bitcoin Wiki](https://en.bitcoin.it/wiki/Main_Page)
* For general questions, please visit our Discord server at https://discord.gg/jf9XX4a
* Ask for help or discuss on [#gridcoin](https://webchat.freenode.net?channels=gridcoin) on Freenode
* You can also join us on [Slack](https://join.slack.com/t/teamgridcoin/shared_invite/enQtMjk2NTI4MzAwMzg0LTE4N2I3ZWZjYWJlZGM1Zjg3MTUyMDhiN2M5NmRmZTA2NDA0ZmY1ZTFmOGM3ZGU2YTBkOTdhNTk2ZjkzMGZkODY/)```

Building
---------------------
The following are developer notes on how to build Gridcoin on your native platform. They are not complete guides, but include notes on the necessary libraries, compile flags, etc.

- [OS X Build Notes](build-macos.md)
- [Unix Build Notes](build-unix.md)
- [Windows Build Notes](build-windows.md)
- [OpenBSD Build Notes](build-openbsd.md)

Running
-------
To create a secure environment for running Gridcoin see:

- [Running Gridcoin](running.md)

Development
---------------------
The Gridcoin repo's [root README](/README.md) contains relevant information on the development process and automated testing.

- [Developer Notes](coding.txt)
- [Release Process](release-process.md)
- [Travis CI](travis-ci.md)

License
---------------------
Distributed under the [MIT software license](/COPYING). 
This product includes software developed by the OpenSSL Project for use in the [OpenSSL Toolkit](https://www.openssl.org/). This product includes
cryptographic software written by Eric Young ([eay@cryptsoft.com](mailto:eay@cryptsoft.com)), and UPnP software written by Thomas Bernard. 
Look at [Assets Attribution](assets-attribution.md) for details.

Copyright (c) 2013 NovaCoin Developers
Copyright (c) 2011-2012 PPCoin Developers

==> Gridcoin-Research-5.4.9.0.tar.gz: Gridcoin-Research-5.4.9.0/doc/README.md <==
Gridcoin
=============

Setup
-----
Gridcoin is a free open source project derived from Bitcoin, with
the goal of providing a long-term energy-efficient cryptocurrency, rewarding BOINC work.
Built on the foundation of Bitcoin, PPCoin and NovaCoin, innovations such as proof-of-stake
help further advance the field of cryptocurrency. The Gridcoin Client downloads and, by default, stores the entire history of Gridcoin transactions; depending on the speed of your computer and network connection, the synchronization process can take anywhere from a few hours to a day or more.

To download Gridcoin, visit [gridcoin.us](https://gridcoin.us).

### Need Help?

* See the documentation at the [Gridcoin Wiki](https://wiki.gridcoin.us/Main_Page)
for help and more information.
* A lot of features core features are based on Bitcoin and have been documented on the [Bitcoin Wiki](https://en.bitcoin.it/wiki/Main_Page)
* For general questions, please visit our Discord server at https://discord.gg/UMWUnMjN4x
* Ask for help or discuss on [#gridcoin](https://web.libera.chat/?channels=#gridcoin) on Libera Chat
* You can also join us on [Slack](https://join.slack.com/t/teamgridcoin/shared_invite/enQtMjk2NTI4MzAwMzg0LTE4N2I3ZWZjYWJlZGM1Zjg3MTUyMDhiN2M5NmRmZTA2NDA0ZmY1ZTFmOGM3ZGU2YTBkOTdhNTk2ZjkzMGZkODY/)

Building
--------
The following are developer notes on how to build Gridcoin on your native platform. They are not complete guides, but include notes on the necessary libraries, compile flags, etc.

- [CMake Build Options](cmake-options.md)
- [OS X Build Notes](build-macos.md)
- [Unix Build Notes](build-unix.md)
- [Windows Build Notes](build-windows.md)
- [Windows (MSYS2) Build Notes](build-msys2.md)
- [FreeBSD Build Notes](build-freebsd.md)
- [OpenBSD Build Notes](build-openbsd.md)

Running
-------
To create a secure environment for running Gridcoin see:

- [Running Gridcoin](running.md)

Development
-----------
The Gridcoin repo's [root README](/README.md) contains relevant information on the development process and automated testing.

- [Developer Notes](coding.txt)
- [Release Process](release-process.md)

License
-------
Distributed under the [MIT software license](/COPYING). 
This product includes software developed by the OpenSSL Project for use in the [OpenSSL Toolkit](https://www.openssl.org/). This product includes
cryptographic software written by Eric Young ([eay@cryptsoft.com](mailto:eay@cryptsoft.com)), and UPnP software written by Thomas Bernard. 
Look at [Assets Attribution](assets-attribution.md) for details.

Copyright (c) 2013 NovaCoin Developers
Copyright (c) 2011-2012 PPCoin Developers
